@@ -1,6 +1,7 @@
 import argparse
 import subprocess
 import os
+import tempfile
 import re
 import sys
 
@@ -236,12 +237,11 @@ def main():
     parser_put_message = subparsers.add_parser("put_message", help="Put a message on a queue")
     parser_put_message.add_argument("queue_name", help="Name of the queue")
     parser_put_message.add_argument("qm_name", help="Name of the queue manager")
-    parser_put_message.add_argument("message", help="Message to put on the queue")
     parser_put_message.set_defaults(func=put_message)
     parser_put_message.epilog = """
     Example usage:
-    ibm-mq-cli put_message DEV.QUEUE.1 QM1 "Hello World"
-    ibm-mq-cli put_message MyQueue MyQueueManager "Test Message"
+    ibm-mq-cli put_message DEV.QUEUE.1 QM1
+    ibm-mq-cli put_message MyQueue MyQueueManager
     """
 
     # Subparser for getting a message from a queue
